%
%   PKSim_test.M   This file provides a simple test case for simulation of the 
%                      Point Kinetics Equations
%
%   This test scenario includes two cases: a single step change and a simple ramp 
%   change in reactivity.  The output of the simulations is P(t) which represents 
%   how the reactor power is expected to behave due to a change in reactivity.
%   No feedback effects are included here.  The feedback-free point kinetics 
%   equations are included within the pkeqns_nofdbk.m function file.
%
%   This simulation code is generic, but the kinetics data used are specific to the 
%   UMLRR. 
%
%   Let's give this a try...
%   
%   File prepared J. R. White, UMass-Lowell (last update:  March 2016)
%

      clear all,  close all,  nfig = 0;  
%%
%   define UMLRR-specific kinetics data and other parameters for the simulations
      [Be,B,Gt,lam,td,S,kappa,nu] = kinetics_data();
      tol  = 1e-5;  options = odeset('RelTol',tol); % error tolerance for ODE solver
      ftime = 600;            % final simulation time (seconds)
%%
%   ***************************************
%   *  Step Change Case 1:  rho = +5 cents  *
%   ***************************************
      tt = [0 ftime];  rhot = [0.05 0.05]*Be;  % specific applied rho(t) 
      rho0 = 0;  Q = 0;       % just critical and no source
      Po = 5000;              % initial power level (W)
      Co = B*Po./(lam*Gt);    % initial precursor conc
      xo = [Po Co]';          % initial condition for state vector
      ftx = @(t,x) pkeqns_nofdbk(t,x,rho0,Q,Be,Gt,B,lam,kappa,nu,tt,rhot);
      [t,x] = ode15s(ftx,[0 ftime],xo,options);  
      P1 = x(:,1)/1000;  t1 = t;   % extract P(t) in kW from full solution
      rhot1 = rhot*100;  tt1 = tt; % also save rho(t) in %Dk/k for later use
%
      nfig = nfig+1;   figure(nfig)
      subplot(2,1,1),plot(tt1,rhot1,'b-','LineWidth',2),grid
      title('Response due to Step Change in \rho')
      ylabel('Reactivity  (%\Deltak/k)'),  ylim([0 0.05]);
      subplot(2,1,2),plot(t1,P1,'r-','LineWidth',2),grid
      xlabel('Time (sec)'),ylabel('Power Level (kW)')
%%
%   *********************************************************
%   *  Ramp Change Case 2:  rho = +5 cents over 10 seconds  *
%   *********************************************************
      tt = [0 10 ftime];  rhot = [0.0 0.05 0.05]*Be;  % specific applied rho(t) 
      rho0 = 0;  Q = 0;       % just critical and no source
      Po = 5000;              % initial power level (W)
      Co = B*Po./(lam*Gt);    % initial precursor conc
      xo = [Po Co]';          % initial condition for state vector
      ftx = @(t,x) pkeqns_nofdbk(t,x,rho0,Q,Be,Gt,B,lam,kappa,nu,tt,rhot);
      [t,x] = ode15s(ftx,[0 ftime],xo,options);  
      P2 = x(:,1)/1000;  t2 = t;   % extract P(t) in kW from full solution
      rhot2 = rhot*100;  tt2 = tt; % also save rho(t) in %Dk/k for later use
%
      nfig = nfig+1;   figure(nfig)
      subplot(2,1,1),plot(tt2,rhot2,'b-','LineWidth',2),grid
      title('Response due to Ramp Change in \rho')
      ylabel('Reactivity  (%\Deltak/k)'),  ylim([0 0.05]);
      subplot(2,1,2),plot(t2,P2,'r-','LineWidth',2),grid
      xlabel('Time (sec)'),ylabel('Power Level (kW)')
%%
%   *******************************************************
%   *  Compare the two simulations: Step vs. Ramp Change  *
%   *******************************************************
      nfig = nfig+1;   figure(nfig)
      subplot(2,1,1),plot(tt1,rhot1,'r-',tt2,rhot2,'b--','LineWidth',2),grid
      title('Response due to Step and Ramp Changes in \rho')
      ylabel('Reactivity  (%\Deltak/k)'),  ylim([0 0.05]);
      legend('Step Change','Ramp Change')
      subplot(2,1,2),plot(t1,P1,'r-',t2,P2,'b--','LineWidth',2),grid
      xlabel('Time (sec)'),ylabel('Power Level (kW)')
      legend('Step Change','Ramp Change')
%   end of program
